Crate rust_release

Crate rust_release 

rust-release

The [rust-release] crate defines a set of types which model a Rust release.

This project is part of the rust-releases and cargo-msrv projects.

In case you have a feature request, question, bug, or have another reason to contact the developers, please create a new issue at the rust-releases repository.

Modules

date
A module for an unrefined Date type, solely used as a version number.
toolchain
Describes toolchains in so far they’re relevant to a release
version
Describes the version of a release Version information for a Rust release.

Structs

Beta
The Beta release channel
Nightly
The Nightly release channel
RustRelease
Type to model a Rust release.
Stable
The Stable release channel

Enums

ReleaseVersion
A combination of a channel and the version number.