Target

Struct Target 

pub struct Target { /* private fields */ }
A target platform

Commonly represented as a target triple. A target triple consists of three (or four) components: the architecture component, the vendor component, the operating system component and optionally a fourth component representing the environment (e.g. gnu or msvc).

Reading materials

Implementations

Source

impl Target

pub const fn host() -> Target

Create a new Target instance which represents the host platform.

The platform on which this library is compiled, will be the host platform.

pub fn try_from_target_triple(triple: &str) -> Result<Target, ParseError>

Create a new Target instance from a target triple.

pub fn from_target_triple_or_unknown(triple: &str) -> Target

Create a new Target instance from a target triple, defaults to unknown-unknown-unknown if the give triple is not recognized.